import{ select, tsv, json, geoPath, zoom, geoMercator, event } from 'd3';
import{ feature } from 'topojson';

const svg = select('svg');


const projection = geoMercator();
const pathGenerator = geoPath().projection(projection);

const g = svg.append('g');

g.append('path')
	.attr('class', 'sphere')
  	.attr('d', pathGenerator({type: 'Sphere'}));


svg.call(zoom().on('zoom', () => {
	g.attr('transform', event.transform)
}));


Promise.all([
  tsv('https://unpkg.com/world-atlas@1/world/50m.tsv'),
  json('https://unpkg.com/world-atlas@1/world/50m.json')
]).then(([tsvData, topoJSONdata]) => {
  
  const countryName = tsvData.reduce((accumulator, d) => {
  	accumulator[d.iso_n3] = d.name;
    return accumulator;
  }, {});
  

  /* ----the code below does the same as the data.reduce function
	  
  const countryName = {};
  tsvData.forEach(d => {
  	countryName[d.iso_n3] = d.name;
  });
  */
  
  
  const countries = feature(topoJSONdata, topoJSONdata.objects.countries);
  console.log(topoJSONdata);
  g.selectAll('path').data(countries.features)
      .enter().append('path')
        .attr('class', 'country')
        .attr('d', pathGenerator)
      .append('title')
  		.text(d => countryName[d.id]);
			
  
  
});